# HG changeset patch
# Node ID 366e634bb9fe
# Parent  d19ef491d1aa
diff --git a/libpurple/account.h b/libpurple/account.h
--- a/libpurple/account.h
+++ b/libpurple/account.h
@@ -230,9 +230,8 @@ void purple_account_notify_added(PurpleA
  * @alias:       The optional alias of the user.
  * @message:     The optional message sent from the user adding you.
  *
- * Notifies the user that the account was addded to a remote user's buddy
- * list and asks ther user if they want to add the remote user to their buddy
- * list.
+ * Notifies the user that the account was added to a remote user's buddy list
+ * and asks the user if they want to add the remote user to their buddy list.
  *
  * This will present a dialog informing the local user that the remote user
  * added them to the remote user's buddy list and will ask if they want to add
diff --git a/libpurple/cmds.h b/libpurple/cmds.h
--- a/libpurple/cmds.h
+++ b/libpurple/cmds.h
@@ -138,7 +138,7 @@ typedef enum {
  *
  * Flags used to set various properties of commands.  Every command should
  * have at least one of #PURPLE_CMD_FLAG_IM and #PURPLE_CMD_FLAG_CHAT set in
- * order to be even slighly useful.
+ * order to be even slightly useful.
  *
  * See purple_cmd_register().
  */
diff --git a/libpurple/connection.c b/libpurple/connection.c
--- a/libpurple/connection.c
+++ b/libpurple/connection.c
@@ -83,10 +83,10 @@ typedef struct
 
 	gboolean is_finalizing;    /* The object is being destroyed. */
 
-	/* The connection error and its description if an error occured */
+	/* The connection error and its description if an error occurred. */
 	PurpleConnectionErrorInfo *error_info;
 
-	guint disconnect_timeout;  /* Timer used for nasty stack tricks         */
+	guint disconnect_timeout;  /* Timer used for nasty stack tricks. */
 } PurpleConnectionPrivate;
 
 /* GObject property enums */
@@ -977,7 +977,7 @@ static void purple_connection_class_init
 }
 
 void
-_purple_connection_new(PurpleAccount *account, gboolean regist, const char *password)
+_purple_connection_new(PurpleAccount *account, gboolean is_registration, const gchar *password)
 {
 	PurpleConnection *gc;
 	PurpleProtocol *protocol;
@@ -994,20 +994,18 @@ void
 
 		message = g_strdup_printf(_("Missing protocol for %s"),
 			purple_account_get_username(account));
-		purple_notify_error(NULL, regist ? _("Registration Error") :
+		purple_notify_error(NULL, is_registration ? _("Registration Error") :
 			_("Connection Error"), message, NULL,
 			purple_request_cpar_from_account(account));
 		g_free(message);
 		return;
 	}
 
-	if (regist)
-	{
-		if (!PURPLE_PROTOCOL_IMPLEMENTS(protocol, SERVER, register_user))
+	if (is_registration) {
+		if (!PURPLE_PROTOCOL_IMPLEMENTS(protocol, SERVER, register_user)) {
 			return;
-	}
-	else
-	{
+		}
+	} else {
 		if (((password == NULL) || (*password == '\0')) &&
 			!(purple_protocol_get_options(protocol) & OPT_PROTO_NO_PASSWORD) &&
 			!(purple_protocol_get_options(protocol) & OPT_PROTO_PASSWORD_OPTIONAL))
@@ -1031,8 +1029,7 @@ void
 
 	g_return_if_fail(gc != NULL);
 
-	if (regist)
-	{
+	if (is_registration) {
 		PurpleConnectionPrivate *priv;
 		purple_debug_info("connection", "Registering.  gc = %p\n", gc);
 
@@ -1042,9 +1039,7 @@ void
 
 		purple_protocol_server_register_user(PURPLE_PROTOCOL_SERVER(protocol),
 		                                     account);
-	}
-	else
-	{
+	} else {
 		purple_debug_info("connection", "Connecting. gc = %p\n", gc);
 
 		purple_signal_emit(purple_accounts_get_handle(), "account-connecting", account);
@@ -1056,7 +1051,7 @@ void
 _purple_connection_new_unregister(PurpleAccount *account, const char *password,
 		PurpleAccountUnregistrationCb cb, gpointer user_data)
 {
-	/* Lots of copy/pasted code to avoid API changes. You might want to integrate that into the previous function when posssible. */
+	/* Lots of copy/pasted code to avoid API changes. You might want to integrate that into the previous function when possible. */
 	PurpleConnection *gc;
 	PurpleProtocol *protocol;
 
diff --git a/libpurple/media.h b/libpurple/media.h
--- a/libpurple/media.h
+++ b/libpurple/media.h
@@ -250,7 +250,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  *
  * Gets the session type from a session
  *
- * Returns: The retreived session type.
+ * Returns: The retrieved session type.
  */
 PurpleMediaSessionType purple_media_get_session_type(PurpleMedia *media, const gchar *sess_id);
 
diff --git a/libpurple/media/backend-fs2.c b/libpurple/media/backend-fs2.c
--- a/libpurple/media/backend-fs2.c
+++ b/libpurple/media/backend-fs2.c
@@ -1972,7 +1972,7 @@ create_stream(PurpleMediaBackendFs2 *sel
 				NULL));
 		}
 
-		/* TURN over SSL is only supported by libnice for Google's "psuedo" SSL mode
+		/* TURN over SSL is only supported by libnice for Google's "pseudo" SSL mode
 			at this time */
 
 		purple_debug_info("backend-fs2",
diff --git a/libpurple/media/backend-iface.h b/libpurple/media/backend-iface.h
--- a/libpurple/media/backend-iface.h
+++ b/libpurple/media/backend-iface.h
@@ -132,7 +132,7 @@ GType purple_media_backend_get_type(void
  *
  * Creates and adds a stream to the media backend.
  *
- * Returns: True if the stream was successfully created, othewise False.
+ * Returns: True if the stream was successfully created, otherwise False.
  */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 gboolean purple_media_backend_add_stream(PurpleMediaBackend *self,
diff --git a/libpurple/media/candidate.h b/libpurple/media/candidate.h
--- a/libpurple/media/candidate.h
+++ b/libpurple/media/candidate.h
@@ -118,7 +118,7 @@ gchar *purple_media_candidate_get_founda
 
 /**
  * purple_media_candidate_get_component_id:
- * @candidate: The candidate to get the compnent id from.
+ * @candidate: The candidate to get the component id from.
  *
  * Gets the component id (rtp or rtcp)
  *
diff --git a/libpurple/mediamanager.h b/libpurple/mediamanager.h
--- a/libpurple/mediamanager.h
+++ b/libpurple/mediamanager.h
@@ -245,7 +245,7 @@ gulong purple_media_manager_set_output_w
  * @manager: The manager the output window was registered with.
  * @output_window_id: The ID of the output window.
  *
- * Remove a previously registerd output window.
+ * Remove a previously registered output window.
  *
  * Returns: TRUE if it found the output window and was successful, else FALSE.
  */
@@ -334,11 +334,11 @@ void purple_media_manager_set_applicatio
  * @blocking: Whether to block until the data was send or not.
  *
  * Sends a buffer of data to a #PURPLE_MEDIA_APPLICATION session.
- * If @blocking is set, unless an error occured, the function will not return
+ * If @blocking is set, unless an error occurred, the function will not return
  * until the data has been flushed into the network.
  * If the stream is not writable, the data will be queued. It is the
- * responsability of the user to stop sending data when the stream isn't
- * writable anymore. It is also the responsability of the user to only start
+ * responsibility of the user to stop sending data when the stream isn't
+ * writable anymore. It is also the responsibility of the user to only start
  * sending data after the stream has been configured correctly (encryption
  * parameters for example).
  *
@@ -360,7 +360,7 @@ gint purple_media_manager_send_applicati
  * with currently available data.
  *
  * Receive a buffer of data from a #PURPLE_MEDIA_APPLICATION session.
- * If @blocking is set, unless an error occured, the function will not return
+ * If @blocking is set, unless an error occurred, the function will not return
  * until @max_size bytes are read.
  *
  * Returns: Number of bytes received or -1 in case of error.
diff --git a/libpurple/memorypool.c b/libpurple/memorypool.c
--- a/libpurple/memorypool.c
+++ b/libpurple/memorypool.c
@@ -74,7 +74,7 @@ purple_memory_pool_block_new(gulong bloc
 	PurpleMemoryPoolBlock *block;
 	gsize total_size;
 
-	/* ceil block struct size to the multipy of align */
+	/* ceil block struct size to the multiply of align */
 	total_size = ((sizeof(PurpleMemoryPoolBlock) - 1) /
 		PURPLE_MEMORY_POOL_BLOCK_PADDING + 1) *
 		sizeof(PurpleMemoryPoolBlock);
diff --git a/libpurple/nat-pmp.c b/libpurple/nat-pmp.c
--- a/libpurple/nat-pmp.c
+++ b/libpurple/nat-pmp.c
@@ -180,7 +180,7 @@ default_gw()
 	mib[0] = CTL_NET;
 	mib[1] = PF_ROUTE; /* entire routing table or a subset of it */
 	mib[2] = 0; /* protocol number - always 0 */
-	mib[3] = 0; /* address family - 0 for all addres families */
+	mib[3] = 0; /* address family - 0 for all address families */
 	mib[4] = NET_RT_DUMP;
 	mib[5] = 0;
 
@@ -513,7 +513,7 @@ purple_pmp_destroy_map(PurplePmpType typ
 }
 
 static void
-purple_pmp_network_config_changed_cb(GNetworkMonitor *monitor, gboolean avialable, gpointer data)
+purple_pmp_network_config_changed_cb(GNetworkMonitor *monitor, gboolean available, gpointer data)
 {
 	pmp_info.status = PURPLE_PMP_STATUS_UNDISCOVERED;
 	g_free(pmp_info.publicip);
diff --git a/libpurple/network.c b/libpurple/network.c
--- a/libpurple/network.c
+++ b/libpurple/network.c
@@ -292,7 +292,7 @@ purple_network_get_handle(void)
 }
 
 static void
-purple_network_upnp_mapping_remove_cb(gboolean sucess, gpointer data)
+purple_network_upnp_mapping_remove_cb(gboolean success, gpointer data)
 {
 	purple_debug_info("network", "done removing UPnP port mapping\n");
 }
diff --git a/libpurple/plugins/log_reader.c b/libpurple/plugins/log_reader.c
--- a/libpurple/plugins/log_reader.c
+++ b/libpurple/plugins/log_reader.c
@@ -1327,7 +1327,7 @@ static char * trillian_logger_read (Purp
 		/* Convert links.
 		 *
 		 * The format is (Link: URL)URL
-		 * So, I want to find each occurance of "(Link: " and replace that chunk with:
+		 * So, I want to find each occurrence of "(Link: " and replace that chunk with:
 		 * <a href="
 		 * Then, replace the next ")" with:
 		 * ">
diff --git a/libpurple/purplechatconversation.h b/libpurple/purplechatconversation.h
--- a/libpurple/purplechatconversation.h
+++ b/libpurple/purplechatconversation.h
@@ -319,7 +319,7 @@ void purple_chat_conversation_clear_user
  * @chat: The chat.
  * @nick: The nick.
  *
- * Sets your nickname (used for hilighting) for a chat.
+ * Sets your nickname (used for highlighting) for a chat.
  */
 void purple_chat_conversation_set_nick(PurpleChatConversation *chat, const gchar *nick);
 
@@ -327,7 +327,7 @@ void purple_chat_conversation_set_nick(P
  * purple_chat_conversation_get_nick:
  * @chat: The chat.
  *
- * Gets your nickname (used for hilighting) for a chat.
+ * Gets your nickname (used for highlighting) for a chat.
  *
  * Returns: The nick.
  */
diff --git a/libpurple/purpleconversation.h b/libpurple/purpleconversation.h
--- a/libpurple/purpleconversation.h
+++ b/libpurple/purpleconversation.h
@@ -34,7 +34,7 @@
  *
  * This is the base class for the conversation abstraction on Libpurple.
  *
- * The present API manages the common functionallity for both kinds of conversations
+ * The present API manages the common functionality for both kinds of conversations
  * @PurpleIMConversation and @PurpleChatConversation.
  */
 
diff --git a/libpurple/purpleconversation.c b/libpurple/purpleconversation.c
--- a/libpurple/purpleconversation.c
+++ b/libpurple/purpleconversation.c
@@ -99,8 +99,8 @@ common_send(PurpleConversation *conv, co
 
 	me = purple_account_get_name_for_display(account);
 
-	/* Always linkfy the text for display, unless we're
-	 * explicitly asked to do otheriwse*/
+	/* Always linkify the text for display, unless we're explicitly asked to do
+	 * otherwise. */
 	if(!(msgflags & PURPLE_MESSAGE_INVISIBLE)) {
 		if(msgflags & PURPLE_MESSAGE_NO_LINKIFY) {
 			displayed = g_strdup(message);
diff --git a/libpurple/purplemarkup.h b/libpurple/purplemarkup.h
--- a/libpurple/purplemarkup.h
+++ b/libpurple/purplemarkup.h
@@ -148,10 +148,9 @@ char *purple_unescape_html(const char *h
 /**
  * purple_markup_slice:
  * @str: The input NUL terminated, HTML, UTF-8 (or ASCII) string.
- * @x: The character offset into an unformatted version of str to
- *          begin at.
- * @y: The character offset (into an unformatted vesion of str) of
- *          one past the last character to include in the slice.
+ * @x: The character offset into an unformatted version of str to begin at.
+ * @y: The character offset (into an unformatted version of str) of one past
+ *     the last character to include in the slice.
  *
  * Returns a newly allocated substring of the HTML UTF-8 string "str".
  * The markup is preserved such that the substring will have the same
diff --git a/libpurple/purplemessage.h b/libpurple/purplemessage.h
--- a/libpurple/purplemessage.h
+++ b/libpurple/purplemessage.h
@@ -101,7 +101,7 @@ typedef enum /*< flags >*/
  * PurpleMessageContentType:
  * @PURPLE_MESSAGE_CONTENT_TYPE_PLAIN: The message has no formatting.
  * @PURPLE_MESSAGE_CONTENT_TYPE_HTML: The message is formatted in HTML.
- * @PURPLE_MESSAGE_CONTENT_TYPE_XHTML: The mesage is formatted in XHTML.
+ * @PURPLE_MESSAGE_CONTENT_TYPE_XHTML: The message is formatted in XHTML.
  * @PURPLE_MESSAGE_CONTENT_TYPE_MARKDOWN: The message is formatted in Markdown.
  *
  * The message formatting for the message.
diff --git a/libpurple/purplepresence.h b/libpurple/purplepresence.h
--- a/libpurple/purplepresence.h
+++ b/libpurple/purplepresence.h
@@ -110,7 +110,7 @@ void purple_presence_set_status_active(P
 
 /**
  * purple_presence_switch_status:
- * @presence: The #PurplePresence instace.
+ * @presence: The #PurplePresence instance.
  * @status_id: The status ID to switch to.
  *
  * Switches the active status in a presence.
diff --git a/libpurple/purpleprotocolclient.h b/libpurple/purpleprotocolclient.h
--- a/libpurple/purpleprotocolclient.h
+++ b/libpurple/purpleprotocolclient.h
@@ -345,7 +345,7 @@ PurpleMood *purple_protocol_client_get_m
  * @client: The #PurpleProtocolClient instance.
  * @conv: A #PurpleConversation instance.
  *
- * Gets the maximum number of charcters per message for @conv.
+ * Gets the maximum number of characters per message for @conv.
  *
  * Returns: The maximum number of characters per message for @conv or -1 for no
  *          limit.
diff --git a/libpurple/purpleprotocolmedia.h b/libpurple/purpleprotocolmedia.h
--- a/libpurple/purpleprotocolmedia.h
+++ b/libpurple/purpleprotocolmedia.h
@@ -115,7 +115,7 @@ gboolean purple_protocol_media_initiate_
  * purple_protocol_media_get_caps:
  * @media: The #PurpleProtocolMedia instance.
  * @account: The #PurpleAccount instance.
- * @who: The user to get the media capabilites for.
+ * @who: The user to get the media capabilities for.
  *
  * Gets the #PurpleMediaCaps for @who which determine what types of media are
  * available.
diff --git a/libpurple/purpleprotocolserver.h b/libpurple/purpleprotocolserver.h
--- a/libpurple/purpleprotocolserver.h
+++ b/libpurple/purpleprotocolserver.h
@@ -190,8 +190,8 @@ void purple_protocol_server_set_info(Pur
  * @connection: The #PurpleConnection instance.
  * @who: The name of the user whose information you're asking for.
  *
- * Gets the user info or profile for @who and displays it in a protocol specifc
- * way.
+ * Gets the user info or profile for @who and displays it in a protocol
+ * specific way.
  *
  * Since: 3.0.0
  */
@@ -291,7 +291,7 @@ void purple_protocol_server_remove_buddy
  * @groups: (element-type PurpleGroup): A #GList of #PurpleGroup's
  *          corresponding to @buddies.
  *
- * Similiar to purple_protocol_server_remove_buddy() but allows you to remove
+ * Similar to purple_protocol_server_remove_buddy() but allows you to remove
  * multiple at a time.
  *
  * If @protocol_server doesn't implement this function directly,
diff --git a/libpurple/request-datasheet.c b/libpurple/request-datasheet.c
--- a/libpurple/request-datasheet.c
+++ b/libpurple/request-datasheet.c
@@ -343,8 +343,8 @@ purple_request_datasheet_record_add(Purp
 	rec->sheet = sheet;
 	rec->key = key;
 
-	/* we don't allow modifying collumn count when datasheet contains
-	 * any records */
+	/* We don't allow modifying column count when datasheet contains any
+	 * records. */
 	rec->data = g_new0(gchar*,
 		purple_request_datasheet_get_column_count(sheet) + 1);
 
diff --git a/libpurple/savedstatuses.h b/libpurple/savedstatuses.h
--- a/libpurple/savedstatuses.h
+++ b/libpurple/savedstatuses.h
@@ -159,7 +159,7 @@ void purple_savedstatus_set_substatus(Pu
  * @account:      The account.
  *
  * Unset a substatus for an account in a saved status.  This clears
- * the previosly set substatus for the PurpleSavedStatus.  If this
+ * the previously set substatus for the PurpleSavedStatus.  If this
  * saved status is activated then this account will use the default
  * status type and message.
  */
diff --git a/libpurple/savedstatuses.c b/libpurple/savedstatuses.c
--- a/libpurple/savedstatuses.c
+++ b/libpurple/savedstatuses.c
@@ -266,7 +266,7 @@ status_to_xmlnode(PurpleSavedStatus *sta
 	{
 		/*
 		 * Purple 1.5.0 and earlier require a name to be set, so we
-		 * do this little hack to maintain backward compatability
+		 * do this little hack to maintain backward compatibility
 		 * in the status.xml file.  Eventually this should be removed
 		 * and we should determine if a status is transient by
 		 * whether the "name" attribute is set to something or if
diff --git a/libpurple/server.h b/libpurple/server.h
--- a/libpurple/server.h
+++ b/libpurple/server.h
@@ -103,7 +103,7 @@ PurpleAttentionType *purple_get_attentio
  * @gc:     The connection over which to send the typing notification.
  * @name:   The name of the buddy we were asking information from.
  *
- * Request user infromation from the server.
+ * Request user information from the server.
  */
 void purple_serv_get_info(PurpleConnection *gc, const char *name);
 
@@ -270,7 +270,7 @@ void purple_serv_got_typing(PurpleConnec
  * @gc: The #PurpleConnection
  * @name: The name of the person that stopped typing.
  *
- * Called from a protocol when it has recieved a type stopped.
+ * Called from a protocol when it has received a type stopped.
  *
  * @todo Could probably move this into the conversation API.
  */
diff --git a/libpurple/server.c b/libpurple/server.c
--- a/libpurple/server.c
+++ b/libpurple/server.c
@@ -553,7 +553,7 @@ void purple_serv_got_im(PurpleConnection
 
 	/*
 	 * Make copies of the message and the sender in case plugins want
-	 * to free these strings and replace them with a modifed version.
+	 * to free these strings and replace them with a modified version.
 	 */
 	buffy = g_strdup(msg);
 	angel = g_strdup(who);
@@ -919,7 +919,7 @@ void purple_serv_got_chat_in(PurpleConne
 
 	/*
 	 * Make copies of the message and the sender in case plugins want
-	 * to free these strings and replace them with a modifed version.
+	 * to free these strings and replace them with a modified version.
 	 */
 	buffy = g_strdup(message);
 	angel = g_strdup(who);
diff --git a/libpurple/theme-loader.h b/libpurple/theme-loader.h
--- a/libpurple/theme-loader.h
+++ b/libpurple/theme-loader.h
@@ -31,7 +31,7 @@
  * SECTION:theme-loader
  * @section_id: libpurple-theme-loader
  * @short_description: <filename>theme-loader.h</filename>
- * @title: Theme Loader Abstact Class
+ * @title: Theme Loader Abstract Class
  *
  * The base class for all theme loaders.
  */
diff --git a/libpurple/theme-manager.h b/libpurple/theme-manager.h
--- a/libpurple/theme-manager.h
+++ b/libpurple/theme-manager.h
@@ -69,14 +69,14 @@ G_DECLARE_FINAL_TYPE(PurpleThemeManager,
 /**
  * purple_theme_manager_init:
  *
- * Initalizes the theme manager.
+ * Initializes the theme manager.
  */
 void purple_theme_manager_init(void);
 
 /**
  * purple_theme_manager_uninit:
  *
- * Uninitalizes the manager then frees all the themes and loaders it is
+ * Uninitializes the manager then frees all the themes and loaders it is
  * responsible for.
  */
 void purple_theme_manager_uninit(void);
diff --git a/libpurple/theme.h b/libpurple/theme.h
--- a/libpurple/theme.h
+++ b/libpurple/theme.h
@@ -30,7 +30,7 @@
  * SECTION:theme
  * @section_id: libpurple-theme
  * @short_description: <filename>theme.h</filename>
- * @title: Theme Abstact Class
+ * @title: Theme Abstract Class
  *
  * The theme API represents the common abilities for all of our supported
  * themes.
diff --git a/libpurple/trie.h b/libpurple/trie.h
--- a/libpurple/trie.h
+++ b/libpurple/trie.h
@@ -70,7 +70,7 @@
  *             #purple_trie_add.
  * @user_data: the user supplied data passed when calling #purple_trie_replace.
  *
- * A funtion called on every matching substring to be replaced.
+ * A function called on every matching substring to be replaced.
  *
  * If you decide to replace the word, append your text to @out and return %TRUE.
  * Otherwise, you must not touch @out. In both cases, you must not do any
diff --git a/libpurple/upnp.h b/libpurple/upnp.h
--- a/libpurple/upnp.h
+++ b/libpurple/upnp.h
@@ -71,7 +71,7 @@ void purple_upnp_uninit(void);
  * @cb_data: (closure): Extra data to be passed to the callback.
  *
  * Sends a discovery request to search for a UPnP enabled IGD that
- * contains the WANIPConnection service that will allow us to recieve the
+ * contains the WANIPConnection service that will allow us to receive the
  * public IP address of the IGD, and control it for forwarding ports.
  * The result will be cached for further use.
  */
diff --git a/libpurple/util.h b/libpurple/util.h
--- a/libpurple/util.h
+++ b/libpurple/util.h
@@ -890,7 +890,7 @@ int purple_utf8_strcasecmp(const char *a
  *
  * Case insensitive search for a word in a string. The needle string
  * must be contained in the haystack string and not be immediately
- * preceded or immediately followed by another alpha-numeric character.
+ * preceded or immediately followed by another alphanumeric character.
  *
  * Returns: TRUE if haystack has the word, otherwise FALSE
  */
diff --git a/libpurple/win32/win32dep.c b/libpurple/win32/win32dep.c
--- a/libpurple/win32/win32dep.c
+++ b/libpurple/win32/win32dep.c
@@ -3,7 +3,7 @@
  *
  * File: win32dep.c
  * Date: June, 2002
- * Description: Windows dependant code for Purple
+ * Description: Windows dependent code for Purple
  *
  * Copyright (C) 2002-2003, Herman Bloggs <hermanator12002@yahoo.com>
  *
diff --git a/libpurple/xfer.c b/libpurple/xfer.c
--- a/libpurple/xfer.c
+++ b/libpurple/xfer.c
@@ -266,7 +266,7 @@ purple_xfer_conversation_write(PurpleXfe
 	purple_xfer_conversation_write_internal(xfer, message, is_error, FALSE);
 }
 
-/* maybe this one should be exported publically? */
+/* maybe this one should be exported publicly? */
 static void
 purple_xfer_conversation_write_with_thumbnail(PurpleXfer *xfer,
 	const gchar *message)
diff --git a/libpurple/xmlnode.h b/libpurple/xmlnode.h
--- a/libpurple/xmlnode.h
+++ b/libpurple/xmlnode.h
@@ -272,7 +272,7 @@ void purple_xmlnode_set_namespace(Purple
 
 /**
  * purple_xmlnode_get_namespace:
- * @node: The node to get the namepsace from
+ * @node: The node to get the namespace from
  *
  * Returns the namespace of a node
  *

diff --git a/libpurple/purpleprivate.h b/libpurple/purpleprivate.h
--- a/libpurple/purpleprivate.h
+++ b/libpurple/purpleprivate.h
@@ -84,8 +84,8 @@ void
 /**
  * _purple_connection_new:
  * @account:  The account the connection should be connecting to.
  * @regist:   Whether we are registering a new account or just
  *                 trying to do a normal signon.
  * @password: The password to use.
  *
  * Creates a connection to the specified account and either connects
@@ -99,8 +99,8 @@ void
  *       in account.c.  If you're trying to sign on an account, use that
  *       function instead.
  */
-void _purple_connection_new(PurpleAccount *account, gboolean regist,
-                            const char *password);
+void _purple_connection_new(PurpleAccount *account, gboolean is_registration,
+                            const gchar *password);
 /**
  * _purple_connection_new_unregister:
  * @account:  The account to unregister
@@ -84,8 +84,8 @@ void
  * _purple_connection_new:
  * @account:  The account the connection should be connecting to.
- * @regist:   Whether we are registering a new account or just
- *                 trying to do a normal signon.
+ * @is_registration: Whether we are registering a new account or just trying to
+ *                   do a normal signon.
  * @password: The password to use.
  *